summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcombobox_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcombobox_imp.h')
-rw-r--r--kjsembed/qtbindings/qcombobox_imp.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kjsembed/qtbindings/qcombobox_imp.h b/kjsembed/qtbindings/qcombobox_imp.h
index 56653345..255e5323 100644
--- a/kjsembed/qtbindings/qcombobox_imp.h
+++ b/kjsembed/qtbindings/qcombobox_imp.h
@@ -17,7 +17,7 @@ class QComboBox;
namespace KJSEmbed {
/**
* Wrapper class for QComboBox methods.
*
* @author Richard Moore, rich@kde.org
*/
@@ -98,7 +98,7 @@ public:
*/
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static QComboBox *toQComboBox( KJS::Object &object );
+ static TQComboBox *toQComboBox( KJS::Object &object );
//
// Constructors implemented by this class.
@@ -174,7 +174,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- QComboBox *instance; // Temp
+ TQComboBox *instance; // Temp
int id;
bool cons;
};
@@ -17,7 +17,7 @@ class QComboBox;
namespace KJSEmbed {
/**
- * Wrapper class for QComboBox methods.
+ * Wrapper class for TQComboBox methods.
*
* @author Richard Moore, rich@kde.org